=========
Changelog
=========

0.4.0 (08-11-2023)
==================

* Upgraded base image to bullseye
* Removed Docker files for CI and refactored so that we don't use Open Forms test images in CI.
* Added code coverage
* Added a label field to the token exchange configuration model

0.3.0 (24-11-2022)
==================

* Upgrade to Python 3.10
* Removed tox
